Potential issues
================

As this package is still under development, it is likely you will run into some issues.

Please report any issue at https://github.com/GuillaumeLNB/lexicons_builder/issues.